@@ -11,7 +11,7 @@ SEXP agg_jpeg_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg,
   
   BEGIN_CPP
     AggDeviceJpegNoAlpha* device = new AggDeviceJpegNoAlpha(
-      CHAR(STRING_ELT(file, 0)), 
+      Rf_translateCharUTF8((STRING_ELT(file, 0))), 
       INTEGER(width)[0], 
       INTEGER(height)[0], 
       REAL(pointsize)[0], 
